@@ -1,4 +1,4 @@
-/* $Id: procsignal.c,v 1.3 2003/10/20 20:12:21 hadess Exp $ */
+/* $Id: procsignal.c,v 1.7 2005/12/12 09:38:10 jamesh Exp $ */
 
 /* Copyright (C)) +998-99 Martin Baulig
    This file is part of LibGTop) +.0.
@@ -21,6 +21,7 @@
    Boston, MA) +2111-1307, USA.
 */
 
+#include <config.h>
 #include <unistd.h>
 #include <sys/vminfo.h>
 #include <sys/resource.h>
@@ -32,7 +33,7 @@
 
 #include "utils.h"
 
-static const unsigned long _glibtop_sysdeps_proc_signal = 
+static const unsigned long _glibtop_sysdeps_proc_signal =
 (1 <<GLIBTOP_PROC_SIGNAL_SIGNAL) + (1 <<GLIBTOP_PROC_SIGNAL_BLOCKED) +
 (1 <<GLIBTOP_PROC_SIGNAL_SIGIGNORE) + (1 <<GLIBTOP_PROC_SIGNAL_SIGCATCH);
 
@@ -54,16 +55,13 @@ glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf,
 	int i;
 	long bit;
 
+	glibtop_init_s (&server, (1L << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
+
 	memset (buf, 0, sizeof (glibtop_proc_signal));
 
 	pinfo = _glibtop_get_procinfo(server, pid);
-	if (pinfo == NULL)
-	{
-		glibtop_error_io_r (server, "Cannot read procsinfo");
+	if (pinfo == NULL) return;
 
-		return;
-	}
-	
 	/* pending signals */
 
 #define NB_BITS	(8 * sizeof(guint64))
@@ -84,6 +82,6 @@ glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf,
 		if (pinfo->pi_signal[i] == (long)SIG_CATCH)
 			buf->sigcatch[i / NB_BITS] |= bit;
 	}
-	
+
 	buf->flags = _glibtop_sysdeps_proc_signal;
 }
