@@ -1,3 +1,4 @@
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 
@@ -20,7 +21,7 @@ get_scaled(const char *buffer, const char *key)
 	char	      *next;
 	unsigned long long value = 0;
 
-	if ((ptr = strstr(buffer, key)))
+	if (G_LIKELY((ptr = strstr(buffer, key))))
 	{
 		ptr += strlen(key);
 		value = strtoull(ptr, &next, 0);
@@ -28,7 +29,10 @@ get_scaled(const char *buffer, const char *key)
 			value *= 1024;
 		else if (strchr(next, 'M'))
 			value *= 1024 * 1024;
-	}
+	} else
+		g_warning("Could not read key '%s' in buffer '%s'",
+			  key, buffer);
+
 	return value;
 }
 
@@ -109,7 +113,10 @@ read_boot_time(glibtop *server)
 
 	btime = strstr(buffer, "btime");
 
-	g_return_val_if_fail(btime != NULL, 0UL);
+	if (!btime) {
+		glibtop_warn_io_r(server, "cannot find btime in /proc/stat");
+		return 0UL;
+	}
 
 	btime = skip_token(btime);
 	return strtoul(btime, NULL, 10);
@@ -143,3 +150,16 @@ get_page_size(void)
 
 	return pagesize;
 }
+
+
+
+gboolean
+check_cpu_line(glibtop *server, const char *line, unsigned i)
+{
+	char start[10];
+
+	g_snprintf(start, sizeof start, "cpu%u", i);
+
+	return g_str_has_prefix(line, start);
+}
+
