@@ -1,9 +1,6 @@
-/* $Id: netlist.c,v 1.1 2004/11/13 12:43:28 bdejean Exp $ */
+/* $Id: netlist.c,v 1.3 2005/12/12 09:38:14 jamesh Exp $ */
 
-/* Copyright (C) 1998-99 Martin Baulig
-   This file is part of LibGTop 1.0.
-
-   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
+/* This file is part of LibGTop 2.0.
 
    LibGTop is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
@@ -21,6 +18,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/netlist.h>
 
@@ -34,10 +32,10 @@ glibtop_init_netlist_s (glibtop *server)
 	server->sysdeps.netlist = _glibtop_sysdeps_netlist;
 }
 
-/* Provides load averange. */
-
-void
+char**
 glibtop_get_netlist_s (glibtop *server, glibtop_netlist *buf)
 {
 	memset (buf, 0, sizeof (glibtop_netlist));
+
+	return NULL;
 }
